@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 # Copyright 2011 andelf <andelf@gmail.com>
 # See LICENSE for details.
-# Time-stamp: <2011-06-05 01:44:27 andelf>
+# Time-stamp: <2011-11-01 17:44:15 wangshuyu>
 
 from qqweibo.auth import OAuthHandler
 from qqweibo.api import API
@@ -12,8 +12,9 @@ from qqweibo.error import QWeiboError
 from qqweibo.cache import MemoryCache, FileCache
 
 
-__all__ = ['OAuthHandler', 'API', 'ModelParser', 'JSONParser',
+__all__ = ['OAuthHandler', 'API', 'QWeiboError', 'version',
            'XMLRawParser', 'XMLDomParser', 'XMLETreeParser',
-           'QWeiboError', 'MemoryCache', 'FileCache', 'version']
+           'ModelParser', 'JSONParser',
+           'MemoryCache', 'FileCache']
 
-version = '0.3.4'
+version = '0.3.9'
